Crate amadeus_streaming

Crate amadeus_streaming 

Harmonious distributed data processing & analysis in Rust.

📦  Crates.io  │  📑  GitHub  │  💬  Chat

This is a support crate of Amadeus and is not intended to be used directly. These types are re-exposed in amadeus::source.

Structs

CountMinSketch
An implementation of a count-min sketch data structure with conservative updating for increased accuracy.
HyperLogLog
An implementation of the HyperLogLog data structure with bias correction.
HyperLogLogMagnitude
Like HyperLogLog but implements Ord and Eq by using the estimate of the cardinality.
NeverEqual
SampleTotal
Given population and sample sizes, returns true if this element is in the sample. Without replacement.
SampleUnstable
Reservoir sampling. Without replacement, and the returned order is unstable.
Sort
This data structure tracks the n top values given a stream. It uses only O(n) space.
Top
This probabilistic data structure tracks the n top keys given a stream of (key,value) tuples, ordered by the sum of the values for each key (the “aggregated value”). It uses only O(n) space.
TopIter
An iterator over the entries and counts in a Top datastructure.

Traits

Intersect
Intersect zero or more &Self to create Option<Self>.
IntersectPlusUnionIsPlus
An optimisation for cases like putting a HyperLogLog inside a Count–min sketch, where intersecting, adding a val, and then unioning that with counters is the same as simply adding the val to the counters.
New
New instances are instantiable given a specified input of <Self as New>::Config.
UnionAssign
Union Self with Rhs in place.