Harmonious distributed data processing & analysis in Rust.
📦 Crates.io │ 📑 GitHub │ 💬 Chat
This is a support crate of Amadeus and is not intended to be used directly. These types are re-exposed in amadeus::source.
Structs
- Count
MinSketch - An implementation of a count-min sketch data structure with conservative updating for increased accuracy.
- Hyper
LogLog - An implementation of the HyperLogLog data structure with bias correction.
- Hyper
LogLog Magnitude - Like
HyperLogLogbut implementsOrdandEqby using the estimate of the cardinality. - Never
Equal - Sample
Total - Given population and sample sizes, returns true if this element is in the sample. Without replacement.
- Sample
Unstable - Reservoir sampling. Without replacement, and the returned order is unstable.
- Sort
- This data structure tracks the
ntop values given a stream. It uses onlyO(n)space. - Top
- This probabilistic data structure tracks the
ntop keys given a stream of(key,value)tuples, ordered by the sum of the values for each key (the “aggregated value”). It uses onlyO(n)space. - TopIter
- An iterator over the entries and counts in a
Topdatastructure.
Traits
- Intersect
- Intersect zero or more
&Selfto createOption<Self>. - Intersect
Plus Union IsPlus - An optimisation for cases like putting a HyperLogLog inside a Count–min sketch, where intersecting, adding a val, and then unioning that with counters is the same as simply adding the val to the counters.
- New
- New instances are instantiable given a specified input of
<Self as New>::Config. - Union
Assign - Union
SelfwithRhsin place.